@@ -5,7 +5,7 @@ use warnings;
 use JSON::PP;
 use List::Util qw(sum min max);
 
-our $VERSION = '0.39';
+our $VERSION = '0.40';
 
 sub new {
     my ($class, %opts) = @_;
@@ -356,6 +356,23 @@ sub run_query {
             next;
         }
 
+        # support for path()
+        if ($part eq 'path') {
+            @next_results = map {
+                if (ref $_ eq 'HASH') {
+                    [ sort keys %$_ ]
+                }
+                elsif (ref $_ eq 'ARRAY') {
+                    [ 0..$#$_ ]
+                }
+                else {
+                    ''
+                }
+            } @results;
+            @results = @next_results;
+            next;
+        }
+
         # standard traversal
         for my $item (@results) {
             push @next_results, _traverse($item, $part);
@@ -622,7 +639,7 @@ JQ::Lite - A lightweight jq-like JSON query engine in Perl
 
 =head1 VERSION
 
-Version 0.39
+Version 0.40
 
 =head1 SYNOPSIS
 
